Un fichier peut être ajouté à un dossier ou à un projet de la même manière d'un ticket.
Vous devez donc de préférence vous positionner sur la page de l'entité à laquelle vous voulez associer le fichier et utiliser l'action correspondante dans le menu déroulant `ajouter`.

